@@ -2,9 +2,9 @@
 
 __copyright__ = "(C) 2006-2009 Ola Skavhaug and Simula Research Laboratory"
 __license__   = "GNU LGPL Version 2.1."
-__cite__      = """Ola Skavhaug, Viper Visualization Software, 
+__cite__      = """Ola Skavhaug, Viper Visualization Software,
 http://www.fenics.org/wiki/viper/"""
-__version__ = "0.4.5"
+__version__ = "0.4.6"
 
 r"""
 Viper
@@ -58,7 +58,7 @@ class Viper(object):
     def __init__(self, *args, **kwargs):
         """
 Create plotter.
-__init__(mesh=mymesh): 
+__init__(mesh=mymesh):
     plot mymesh
 __init__(x=x, mesh=mymesh):
     plot scalar of vector field x over mymesh
@@ -114,11 +114,11 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         if self.mesh is not None:
             self.vtkgrid = self.make_vtk_grid(self.mesh, cell_type=celltype)
             self.filter = self.vtkgrid
-            
+
         vmin = kwargs.get("vmin", x.min())
         vmax = kwargs.get("vmax", x.max())
         minmax = vmax - vmin
-        
+
         self.displacement = self._resolve_displacement(displacement)
 
         self.frame = kwargs.get("frame", None)
@@ -126,11 +126,11 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         # Extract cut plane information
         cutplane_origin = kwargs.get("cutplane_origin", None)
         cutplane_normal = kwargs.get("cutplane_normal", (0,0,1))
-        
+
         if len(x.shape) == 1:
             if self.warpscalar and minmax > 0:
                 self.filter = self.warp_scalar(self.x, minmax)
-            
+
             # If plot a cut plane
             if not cutplane_origin is None:
                 self.filter = self._cutplane_filter(cutplane_origin, cutplane_normal)
@@ -141,10 +141,10 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
                 # Position the camera normal to the plane with focus on the center of the cutplane
                 cutplane_normal    = numpy.asarray(cutplane_normal,dtype = 'd')
                 camera_focal_point = numpy.asarray(self.filter.GetCenter(), dtype = 'd')
-                
+
                 #Normalize the cutplane normal
                 cutplane_normal /= numpy.sqrt(numpy.dot(cutplane_normal,cutplane_normal))
-                
+
                 # Check which component is the largest in the cutplane normal
                 if cutplane_normal.argmax() in [0,1]:
                     # If the largest direction is in the x or y direction, let z be the up direction
@@ -156,15 +156,15 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
                 # Set view_up as a projection of the cutplane normal onto the up_direction
                 # NOTE: Actually no need for the projection, vtk do the projection for you...
                 view_up = up_direction - numpy.dot(up_direction,cutplane_normal)*cutplane_normal
-                
+
                 # Set the camera position
                 self.ren.GetActiveCamera().SetPosition(camera_focal_point + cutplane_normal)
                 self.ren.GetActiveCamera().SetFocalPoint(camera_focal_point)
                 self.ren.GetActiveCamera().SetViewUp(view_up)
                 self.ren.ResetCamera(self.filter.GetBounds())
                 # It is sometimes nice to dolly the view but sometimes not
-                #self.ren.GetActiveCamera().Dolly(1.5) 
-            
+                #self.ren.GetActiveCamera().Dolly(1.5)
+
         else:
             self.mode="vector"
             if self.mesh is not None:
@@ -282,7 +282,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         else:
             self.filter = self.warp_scalar(d)
             return d
-        
+
     def initcommon(self, kwargs):
         self.displacement = kwargs.get("displacement", None)
         self.title = kwargs.get("title", "FEniCS Viper")
@@ -363,7 +363,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         self.basename = filebasename
         self.filecounter = -1
         self.writer.SetInput(self.vtkgrid)
-        
+
         w2if = vtk.vtkWindowToImageFilter()
         w2if.SetInput (self.renWin)
         self.pngwriter = vtk.vtkPNGWriter()
@@ -380,7 +380,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
             self.pdffilecounter = -1
         except:
             print "Could not import vtkGL2PSExporter from vtk. Saving pdf, eps, and ps files will not be possible."
-            
+
         self.rawfilecounter = -1
 
     def write_xml(self, filename=None, map=None):
@@ -398,7 +398,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         x = self.x.copy()
         if map is not None:
             x[:] = x[map]
-        for i,v in enumerate(x): 
+        for i,v in enumerate(x):
             tf.write('    <entity index="%d" value="%f"/>\n' % (i,v))
         tf.write("""\
   </meshfunction>
@@ -419,7 +419,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         self.writer.Write()
 
     def write_png(self, filename=None):
-        """Write a simulation frame to file in png format.""" 
+        """Write a simulation frame to file in png format."""
         if not self.is_writer: self.init_writer()
         self.pngfilecounter += 1
         if filename is None:
@@ -430,7 +430,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         self.pngwriter.Write()
 
     def write_ps(self, filename=None, compress = False, format = "eps"):
-        """Write a simulation frame to file in eps/ps/pdf format.""" 
+        """Write a simulation frame to file in eps/ps/pdf format."""
         if not self.is_writer: self.init_writer()
         assert(isinstance(format,str))
         if compress:
@@ -454,13 +454,13 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         if filename is None:
             filename = "%s%.4d" % (self.basename, counter)
         self.pswriter.SetFilePrefix(filename)
-        
+
         self._update()
         self.pswriter.Write()
 
     def write_raw(self, sol=None, dofmap=None):
         """Write a simulation frame to file, i.e. dump the numpy array to file
-        in binary format.""" 
+        in binary format."""
         if not self.is_writer: self.init_writer()
         #self._update(sol)
         self.rawfilecounter += 1
@@ -494,9 +494,9 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
                 if self.cleanup:
                     for f in self.files:
                         os.remove(f)
-  
-        start = 0 
-        stop = self.pngfilecounter 
+
+        start = 0
+        stop = self.pngfilecounter
         if stop < 0:
             print "No scenes written as png files. Giving up."
             return
@@ -527,7 +527,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         self.azimuth_incr = a;   # 1 (degree) is a good value
         self.elevator_incr = e;  # 1 (degree) is a good value
         self.max_elevation = m;
-        
+
     def _make_lut(self, autorange=(0,0)):
         lut = vtk.vtkLookupTable()
         lutfile = os.path.join(lutdir, self.lutfile)
@@ -537,10 +537,16 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
             vals = [x.split() for x in open(lutfile,'r').readlines()[1:]]
             lut.SetNumberOfColors(len(vals))
             lut.Build()
-            for i in range(len(vals)): 
+            for i in range(len(vals)):
                 if len(vals[i]) == 4:
                     lut.SetTableValue(i, *[float(x) for x in vals[i]]),
         else:
+            lut.SetTableRange (0, 1);
+            lut.SetHueRange (0, 0);
+            lut.SetSaturationRange (0, 0);
+            lut.SetValueRange (0, 1);
+
+        if False:
             ctable = [[1, 0, 0, 1],
                       [0, 1, 0, 1],
                       [0, 0, 1, 1],
@@ -549,7 +555,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
                       [1, 0, 1, 1],
                       [0, 1, 1, 1]
                       ]
-                        
+
             rmin, rmax = autorange
             ncols = int(rmax-rmin)+1
             lut.SetNumberOfColors(ncols)
@@ -590,40 +596,40 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
             inttype = numpy.int32
         elif VTK_ID_TYPE_SIZE == 8:
             inttype = numpy.int64
-        
+
         # Create a cell array, stored in Python.numpy
         ncells = len(nl)
         cells = numpy.zeros((ncells, cellsize), dtype=inttype)
-        
+
         cells[:,1:cellsize] = nl
-        cells[:,0] = cellsize - 1 
-        
+        cells[:,0] = cellsize - 1
+
         a = numpy.ravel(cells)
         ita = vtk.vtkIdTypeArray()
         ita.SetVoidArray(a, len(a), 1)
         ca = vtk.vtkCellArray()
         ca.SetCells(ncells,ita)
-        
-        
+
+
         # Create some points
         npoints = len(cl)
         pts = numpy.ravel(cl)
-        
+
         pa = vtk.vtkDoubleArray()
         pa.SetNumberOfComponents(3)
         pa.SetVoidArray(pts, npoints*3, 1)
-        
+
         self.refs = [a, pts]
-        
+
         v = vtk.vtkPoints()
         v.SetNumberOfPoints(npoints)
         v.SetData(pa)
-        
+
         # Create an unstructured grid.
         us = vtk.vtkUnstructuredGrid()
         us.SetPoints(v)
         us.SetCells(celltype, ca)
-        
+
         return us
 
     def vec3d(self, x):
@@ -635,7 +641,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
             x[:,:m] = x_old
         return x
 
-    
+
     def update(self, x=None):
         """Update plot data."""
 
@@ -751,7 +757,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         coordinates = coords_3d
         directions = directions_3d
         m = 3
-        
+
         vtkpoints = vtk.vtkDoubleArray()
         vtkpoints.SetNumberOfComponents(m)
         vtkpoints.SetVoidArray(coordinates, n*m, m)
@@ -807,7 +813,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         if abs(vmax) < 1e-16:
             vmax = 1.0
         return scale/vmax*self.__D/(n**(1.0/d))
-        
+
 
     def vector_plotter(self, coords, x, vmin, vmax, wireframe=False, sf=2.0):
         import operator
@@ -868,7 +874,7 @@ Viper specific:
 * Keypress i: write image to file in png format
 * Keypress m: write image to file in eps format
 * Keypress n: write image to file in pdf format
-* Keypress o: add outline 
+* Keypress o: add outline
 * Keypress h: display this message
 
 Inherited from vtk:
@@ -966,11 +972,11 @@ Inherited from vtk:
 
     def enable_event(self, obj, event):
         self.glyphActor.VisibilityOn()
-        print "Interaction is ON, press again to turn off."        
+        print "Interaction is ON, press again to turn off."
 
     def disable_event(self, obj, event):
         self.glyphActor.VisibilityOff()
-        print "Interaction is OFF, press again to turn on."        
+        print "Interaction is OFF, press again to turn on."
 
     def probe_data(self, obj, event):
         self.glyphActor.VisibilityOff()
@@ -1055,7 +1061,7 @@ Inherited from vtk:
         probe = vtk.vtkProbeFilter()
         probe.SetInput(point)
         probe.SetSource(data)
-        
+
         # create glyph
         cone = vtk.vtkConeSource()
         cone.SetResolution(16)
@@ -1117,7 +1123,7 @@ Inherited from vtk:
             self.add_point_labels()
 
         return self.iren, self.renWin, self.ren
-    
+
 
     def add_point_labels(self, labels=None):
         # Generate data arrays containing point and cell ids
@@ -1148,7 +1154,7 @@ Inherited from vtk:
 
             print "arr.GetName():", arr.GetName()
             n = arr.GetNumberOfTuples()
-            print "n = ", n 
+            print "n = ", n
             x = numpy.zeros(n, dtype='i')
             arr.ExportToVoidPointer(x)
             print "X:", x
@@ -1191,15 +1197,15 @@ Inherited from vtk:
 
 
     def plot_xy(self,xd,yd,linespec):
-        
+
         xVal = vtk.vtkFloatArray()
         yVal = vtk.vtkFloatArray()
-        
+
         for i in range(len(xd)):
             xVal.InsertNextTuple1(xd[i])
             yVal.InsertNextTuple1(yd[i])
-            
-        curve = vtk.vtkRectilinearGrid()   
+
+        curve = vtk.vtkRectilinearGrid()
         curve.SetDimensions(len(xd), 1, 1)
         curve.SetXCoordinates(xVal)
         curve.GetPointData().SetScalars(yVal)
@@ -1208,16 +1214,16 @@ Inherited from vtk:
         xyplot = vtk.vtkXYPlotActor()
 
         text_prop = xyplot.GetTitleTextProperty()
-        text_prop.SetColor(1.0, 1.0, 1.0)
+        text_prop.SetColor(.0, .0, .0)
         text_prop.SetFontFamilyToArial()
-    
+
         xyplot.AddInput(curve)
-        xyplot.GetProperty().SetColor(1,1,1)
+        xyplot.GetProperty().SetColor(0.0,0.0,0.0)
         xyplot.SetBorder(10)
         xyplot.GetPositionCoordinate().SetValue(0.0, 0.0, 0)
         xyplot.GetPosition2Coordinate().SetValue(1.0, 1.0, 0)
-        xyplot.GetProperty().SetLineWidth(1)
-        xyplot.GetProperty().SetPointSize(5)
+        xyplot.GetProperty().SetLineWidth(2)
+        xyplot.GetProperty().SetPointSize(7)
         xyplot.SetPlotColor(0,1,0,0)
         xyplot.PlotPointsOff()
         xyplot.PlotLinesOff()
@@ -1229,7 +1235,7 @@ Inherited from vtk:
         xyplot.SetTitleTextProperty(text_prop)
         xyplot.SetDataObjectXComponent(0,0)
         xyplot.SetDataObjectYComponent(0,1)
-        
+
         # determine line style
         if linespec == ".":
             xyplot.PlotCurvePointsOn()
@@ -1243,16 +1249,16 @@ Inherited from vtk:
         else:
             print "Invalid line spec. Exiting"
             exit(0)
-        
+
         # set up the renderer
         ren = vtk.vtkRenderer()
-        ren.SetBackground(0.2,0.2,0.2)
+        ren.SetBackground(1,1,1)
         ren.AddActor(xyplot)
-        
+
         renWin = vtk.vtkRenderWindow()
         renWin.AddRenderer(ren)
         renWin.SetSize(self.window_size)
-        
+
         # interaction
         iren = vtk.vtkRenderWindowInteractor()
         iren.SetRenderWindow(renWin)
@@ -1266,7 +1272,7 @@ Inherited from vtk:
         sphere.SetPhiResolution(phi_res)
         sphere.SetRadius(rad)
         sphere.SetCenter(*pt)
-        
+
         sactor = self.sphere_actors[-1]
 
         self.sphere_data.AddInput(sphere.GetOutput())
@@ -1309,7 +1315,7 @@ Inherited from vtk:
         if mapper is None:
             mapper = vtk.vtkPolyDataMapper()
             actor.SetMapper(mapper)
-        
+
         mapper.SetInput(self.polygon_data.GetOutput())
         actor.GetProperty().SetColor(0, 0, 1)
         actor.GetProperty().SetLineWidth(1)
@@ -1338,12 +1344,12 @@ Inherited from vtk:
         """ Return a cut plan data """
         if not self.mesh.cells().shape[1] == 4:
             raise RuntimeError, "Can only cut scalar 3 dimensional plots"
-        
-        if not (isinstance(origo, (numpy.ndarray, tuple, list)) and 
+
+        if not (isinstance(origo, (numpy.ndarray, tuple, list)) and
                 len(origo) == 3):
             raise RuntimeError, "Provide a tuple, list or numpy array of length 3 for cutplane_origo"
-        
-        if not (isinstance(normal, (numpy.ndarray, tuple, list)) and 
+
+        if not (isinstance(normal, (numpy.ndarray, tuple, list)) and
                 len(normal) ==3):
             raise RuntimeError, "Provide a tuple, list or numpy array of length 3 for cutplane_normal"
 
@@ -1358,7 +1364,7 @@ Inherited from vtk:
         cutter.SetInput(self.filter)
         cut_data = cutter.GetOutput()
         return cut_data
-        
+
 
     def set_sphere_opacity(self, val):
         """Change the sphere opacity (range [0,1])."""
