@@ -4,8 +4,7 @@ __copyright__ = "(C) 2006-2009 Ola Skavhaug and Simula Research Laboratory"
 __license__   = "GNU LGPL Version 2.1."
 __cite__      = """Ola Skavhaug, Viper Visualization Software,
 http://www.fenics.org/wiki/viper/"""
-__version__ = "0.4.5"
-
+__version__ = "0.4.6"
 
 __doc__ = """
 Viper for DOLFIN
@@ -237,6 +236,7 @@ class Viper(ViperBase):
 
     def plot_meshfunction(self, data, *args, **kwargs):
         self.mesh = data.mesh()
+        mesh_dim = self.mesh.topology().dim()
         dim = data.dim()
         size = data.size()
         values = data.values()
@@ -245,15 +245,26 @@ class Viper(ViperBase):
         self.x = numpy.array(values, dtype='d')
         if str(values.dtype).count("int"):
             self.lutfile = ""
-        if size in (self.mesh.num_vertices(), self.mesh.num_cells()):
-            if dim==self.mesh.topology().dim(): # meshfunction over cells
+        if dim in (0, mesh_dim-1, mesh_dim):
+            if dim==mesh_dim: # meshfunction over cells
                 self.vertex_plot = False
                 self.lutfile = ""
+            elif dim==mesh_dim-1: # meshfunction over faces
+                # Create a vertex valued meshfunction and plot that
+                self.mesh.init(dim)
+                vertices = type(data)(self.mesh, 0)
+                vertex_values = vertices.values()
+                vertex_values[:] = 0
+                con20 = self.mesh.topology()(dim,0)
+                for facet in xrange(self.mesh.num_faces()):
+                    if values[facet]:
+                        vertex_values[con20(facet)] = values[facet]
+                self.plot_meshfunction(vertices, *args, **kwargs)
+                return
+
             (self.iren, self.renWin, self.ren) = self.simple_plotter(self.filter, self.x.min(), self.x.max(), wireframe=False)
         else:
-            print "Unknown size %d" % size
-            print "Valid size are v(%d) and c(%d)" % (self.mesh.num_vertices(), self.mesh.num_cells())
-            raise RuntimeError, "Only vertex and cell valued meshfunctions can be plotted"
+            raise RuntimeError, "Only vertex, facets and cell valued meshfunctions can be plotted"
         self.iren.Initialize()
         self._update(self.x)
         self.renWin.Render()
